@@ -3,17 +3,14 @@
 use strict;
 use warnings;
 
-our $VERSION = '1.003';
-
-use lib 'lib';
+our $VERSION = '1.005';
 
 use Module::ScanDeps::Static;
 
 __PACKAGE__->main();
 
 sub main {
-
-  exit Module::ScanDeps::Static->main;
-} ## end sub main
+  return Module::ScanDeps::Static->main;
+}
 
 1;
