@@ -11,7 +11,7 @@ use English qw(-no_match_vars);
 use File::Find;
 use File::Temp qw(tempfile);
 use File::Basename qw(fileparse);
-use List::Util qw(any none uniq);
+use List::Util qw(any none);
 use JSON;
 use Module::ScanDeps::Static;
 use Scalar::Util qw(reftype);
@@ -26,10 +26,9 @@ Readonly::Scalar our $EMPTY   => q{};
 Readonly::Scalar our $SUCCESS => 0;
 Readonly::Scalar our $FAILURE => 1;
 
-Readonly::Scalar our $MIN_PERL_VERSION => $PERL_VERSION;
+Readonly::Scalar our $MIN_PERL_VERSION => '5.10.1';
 
-require Module::ScanDeps::Static::VERSION;
-our $VERSION = '1.7.8';
+our $VERSION = '1.005';
 
 use parent qw(CLI::Simple);
 
@@ -67,7 +66,7 @@ sub find_requires {
 
     my $scanner = Module::ScanDeps::Static->new(
       { core             => $include_core,
-        include_require  => $self->get_include_require,
+        include_require  => $TRUE,
         path             => $f,
         min_core_version => $min_perl_version,
       }
@@ -243,7 +242,7 @@ sub get_file_listing {
             if @exclude_paths && any { $File::Find::dir =~ /^$_/xsm } @exclude_paths;
 
           return
-            if /^[.]/xsm || !/[.]p(?:[ml])$/xsm;
+            if /^[.]/xsm || !/[.]p(:?m|l)$/xsm;
 
           die 'done'
             if !$self->get_recurse && $path ne $File::Find::dir;
@@ -368,32 +367,9 @@ sub list_requires {
 
   my $requires = $self->find_requires( files => $self->list_files( format => $EMPTY ) );
 
-  $requires = $self->filter_provided($requires);
-
   return $self->_format( $requires, format => $format );
 }
 
-########################################################################
-sub filter_provided {
-########################################################################
-  my ( $self, $requires ) = @_;
-
-  my @provided = grep { $_ !~ /[.]pl$/xsm } @{ $self->get_file_listing( path => $self->get_path ) };
-
-  my @packages = uniq $self->get_package_list( files => \@provided );
-
-  my %modules = map { $_->{name} => 1 } @{$requires};
-
-  foreach (@packages) {
-    next
-      if !$modules{$_};
-
-    delete $modules{$_};
-  }
-
-  return [ grep { $modules{ $_->{name} } } @{$requires} ];
-}
-
 ########################################################################
 sub create_requires {
 ########################################################################
@@ -486,7 +462,7 @@ sub dump_map {
 
   foreach my $f (@filter_list) {
     foreach my $file ( keys %requirements ) {
-      foreach my $m ( keys %{ $requirements{$file} } ) {
+      foreach my $m ( keys $requirements{$file} ) {
         next if $m !~ /^$f/xsm;
         delete $requirements{$file}->{$m};
       }
@@ -499,8 +475,7 @@ sub dump_map {
   else {
     foreach my $m ( keys %requirements ) {
       print {$fh} sprintf "%s\n", $m;
-      my @map_w_version
-        = map { sprintf "\t%s, %s\n", $_, $requirements{$m}->{$_} } sort keys %{ $requirements{$m} };
+      my @map_w_version = map { sprintf "\t%s, %s\n", $_, $requirements{$m}->{$_} } sort keys $requirements{$m};
       print {$fh} join q{}, @map_w_version;
     }
 
@@ -691,7 +666,6 @@ sub main {
     filter|F=s
     file-list|L=s
     format|t=s
-    help|h
     max-items|m=i
     min-perl-version=s
     module-version=s
@@ -701,14 +675,13 @@ sub main {
     progress-bar|P!
     recurse|R!
     requires|r=s
-    include-require|i!
     update|u
     versions|v
   );
 
   my $cli = Module::ScanDeps::FindRequires->new(
     option_specs    => \@option_specs,
-    default_options => { path => getcwd, 'include-require' => $TRUE },
+    default_options => { path => getcwd },
     extra_options   => [qw(files packages requires_map filter_list)],
     commands        => {
       'create-cpanfile' => \&create_cpanfile,
@@ -756,18 +729,16 @@ __END__
 
 =head1 NAME
 
-Module::ScanDeps::FindRequires
+find-requires.pl
 
 =head1 SYNOPSIS
 
- find-requires --path src/main/perl list-requires
+ find-requires.pl --path src/main/perl list-requires
 
- find-requires --path src/main/perl dump-map
+ find-requires.pl --path src/main/perl dump-map
 
  Script to maintain a manifest of Perl module dependencies for a project.
 
-I<NOTE: find-requires.ps1 should be used when running under Windows.>
-
 =head1 DESCRIPTION
 
 C<find-requires.pl> is a script to help you find and maintain a list
@@ -883,26 +854,26 @@ you are executing the script from the root of your application.>
 
 =item * create the C<requires> file the first time
 
-   find-requires --path src/main/perl create-requires > requires
+   find-requires.pl --path src/main/perl create-requires > requires
 
 =item * check to see if a module has a new requirement
 
-   find-requires -f src/main/perl/lib/TreasurersBriefcase/Foo.pm check-requires
+   find-requires.pl -f src/main/perl/lib/TreasurersBriefcase/Foo.pm check-requires
 
 =item * add new dependencies to the C<requires> file
 
-   find-requires --module Foo --module-version 0.1 add-requires
+   find-requires.pl --module Foo --module-version 0.1 add-requires
 
-   find-requires --file myscript.pl check-requires | \
-      find-requires -u add-requires
+   find-requires.pl --file myscript.pl check-requires | \
+      find-requires.pl -u add-requires
 
 =item * delete a module from the C<requires> file
 
-  find-requires -M Foo::Bar::Baz -u delete-requires
+  find-requires.pl -M Foo::Bar::Baz -u delete-requires
 
 =item * create a cpanfile from the C<requires> file
 
-   find-requires create-cpanfile
+   find-requires.pl create-cpanfile
 
 =item * create listing of each file and its dependencies
 
